==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'باز تنظيم',
	'boxstr_close' => 'بستن',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'بعدي',
	'boxstr_previous' => 'قبلي',
	'boxstr_slideshowStart' => 'اسلايد شو',
	'boxstr_slideshowStop' => 'ايست',
	'boxstr_zoom' => 'زوم',

	// E
	'explication_selecteur' => 'عنصر هدف كه جعبه را به حركت در مي‌آورد مشخص كنيد. (jQuery  يا عبارت سي.اس.اس)',
	'explication_selecteur_galerie' => 'عناصر هدف را مشخص كنيد تا در يك گروه در يك گالري يكي شوند. (عبارت سي.اس.اس ياjQuery) ',
	'explication_splash_url' => 'يو.آر.ال رسانه را وارد كنيد تا به صورت خودكار در چارگوش در نخستين ويزيت در سايت همگاني به نمايش درآيد. ',
	'explication_traiter_toutes_images' => 'گنجاندن يك كادر دور تمام تصويرها؟',

	// L
	'label_active' => 'فعال‌سازي كادر مديا در سايت همگاني ',
	'label_apparence' => 'ظهور',
	'label_aucun_style' => 'پيش گزيده هيچ كادري استفاده نكن',
	'label_choix_transition_elastic' => 'انعطاف‌ پذير',
	'label_choix_transition_fade' => 'فيد همزمان',
	'label_choix_transition_none' => 'بدون اثر انتقال ',
	'label_maxheight' => 'بيشترين ارتفاع (پيكسل يا %)',
	'label_maxwidth' => 'بيشترين پهنا (پيكس يا %)',
	'label_minheight' => 'كم‌ترين ارتفاع (پيكس يا %)',
	'label_minwidth' => 'كم‌ترين پهنا (پيكس يا %)',
	'label_opacite' => 'كدري پسزمينه',
	'label_selecteur_commun' => 'به طور كلي ',
	'label_selecteur_galerie' => 'به حالت گالري',
	'label_skin' => 'پوشش ديدني',
	'label_slideshow_speed' => 'زمان نمايش تصاوير اسلايد شو (م‌س)',
	'label_speed' => 'سرعت انتقال (م‌س)',
	'label_splash' => 'جعبه‌ي نمايش',
	'label_splash_url' => 'يو.آر.ال براي نمايش ',
	'label_traiter_toutes_images' => 'تصاوير',
	'label_transition' => 'انتقال بين دو نمايش ',

	// T
	'titre_menu_box' => 'جعبه‌ي مديا',
	'titre_page_configurer_box' => 'پيكربندي جعبه‌ي مديا'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_reinitialiser' => 'باز تنظيم',
	'boxstr_close' => 'بستن',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'بعدي',
	'boxstr_previous' => 'قبلي',
	'boxstr_slideshowStart' => 'اسلايد شو',
	'boxstr_slideshowStop' => 'ايست',
	'boxstr_zoom' => 'زوم',

	// E
	'explication_selecteur' => 'عنصر هدف كه جعبه را به حركت در مي‌آورد مشخص كنيد. (jQuery  يا عبارت سي.اس.اس)',
	'explication_selecteur_galerie' => 'عناصر هدف را مشخص كنيد تا در يك گروه در يك گالري يكي شوند. (عبارت سي.اس.اس ياjQuery) ',
	'explication_splash_url' => 'يو.آر.ال رسانه را وارد كنيد تا به صورت خودكار در چارگوش در نخستين ويزيت در سايت همگاني به نمايش درآيد. ',
	'explication_traiter_toutes_images' => 'گنجاندن يك كادر دور تمام تصويرها؟',

	// L
	'label_active' => 'فعال‌سازي كادر مديا در سايت همگاني ',
	'label_apparence' => 'ظهور',
	'label_aucun_style' => 'پيش گزيده هيچ كادري استفاده نكن',
	'label_choix_transition_elastic' => 'انعطاف‌ پذير',
	'label_choix_transition_fade' => 'فيد همزمان',
	'label_choix_transition_none' => 'بدون اثر انتقال ',
	'label_maxheight' => 'بيشترين ارتفاع (پيكسل يا %)',
	'label_maxwidth' => 'بيشترين پهنا (پيكس يا %)',
	'label_minheight' => 'كم‌ترين ارتفاع (پيكس يا %)',
	'label_minwidth' => 'كم‌ترين پهنا (پيكس يا %)',
	'label_opacite' => 'كدري پسزمينه',
	'label_selecteur_commun' => 'به طور كلي ',
	'label_selecteur_galerie' => 'به حالت گالري',
	'label_skin' => 'پوشش ديدني',
	'label_slideshow_speed' => 'زمان نمايش تصاوير اسلايد شو (م‌س)',
	'label_speed' => 'سرعت انتقال (م‌س)',
	'label_splash' => 'جعبه‌ي نمايش',
	'label_splash_url' => 'يو.آر.ال براي نمايش ',
	'label_traiter_toutes_images' => 'تصاوير',
	'label_transition' => 'انتقال بين دو نمايش ',

	// T
	'titre_menu_box' => 'جعبه‌ي مديا',
	'titre_page_configurer_box' => 'پيكربندي جعبه‌ي مديا',
];
